==> haskell-wuss-2.0.1.2-3-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-wuss.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 wuss
version:              2.0.1.2
visibility:           public
id:                   wuss-2.0.1.2-GFcyeZ9mhGsEsADEBna08E
key:                  wuss-2.0.1.2-GFcyeZ9mhGsEsADEBna08E
license:              MIT
maintainer:           Taylor Fausak
synopsis:             Secure WebSocket (WSS) clients
description:
    Wuss is a library that lets you easily create secure WebSocket clients over
    the WSS protocol. It is a small addition to
    <https://hackage.haskell.org/package/websockets the websockets package> and
    is adapted from existing solutions by
    <https://gist.github.com/jaspervdj/7198388 @jaspervdj>,
    <https://gist.github.com/mpickering/f1b7ba3190a4bb5884f3 @mpickering>, and
    <https://gist.github.com/elfenlaid/7b5c28065e67e4cf0767 @elfenlaid>.

category:             Network
abi:                  c949200571a0ac78c245ff081e01fb66
exposed:              True
exposed-modules:      Wuss
import-dirs:          /usr/lib/ghc-9.4.8/site-local/wuss-2.0.1.2
library-dirs:         /usr/lib/ghc-9.4.8/site-local/wuss-2.0.1.2
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/wuss-2.0.1.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-wuss
hs-libraries:         HSwuss-2.0.1.2-GFcyeZ9mhGsEsADEBna08E
depends:
    base-4.17.2.1 bytestring-0.11.5.3
    crypton-connection-0.4.1-Cps42ulH82v9fpxac7KbQy exceptions-0.10.5
    network-3.1.4.0-82nHJL6Luo48oDimrIyJyV
    websockets-0.12.7.3-Cme1muM4GT63a7RFWHfq2k

haddock-interfaces:   /usr/share/doc/haskell-wuss/html/wuss.haddock
haddock-html:         /usr/share/doc/haskell-wuss/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-wuss-2.0.1.2-4-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-wuss.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 wuss
version:              2.0.1.2
visibility:           public
id:                   wuss-2.0.1.2-ExKSQnZ8Vg4EuTi7M7pWOx
key:                  wuss-2.0.1.2-ExKSQnZ8Vg4EuTi7M7pWOx
license:              MIT
maintainer:           Taylor Fausak
synopsis:             Secure WebSocket (WSS) clients
description:
    Wuss is a library that lets you easily create secure WebSocket clients over
    the WSS protocol. It is a small addition to
    <https://hackage.haskell.org/package/websockets the websockets package> and
    is adapted from existing solutions by
    <https://gist.github.com/jaspervdj/7198388 @jaspervdj>,
    <https://gist.github.com/mpickering/f1b7ba3190a4bb5884f3 @mpickering>, and
    <https://gist.github.com/elfenlaid/7b5c28065e67e4cf0767 @elfenlaid>.

category:             Network
abi:                  1619c399df96308ffacee0f059876516
exposed:              True
exposed-modules:      Wuss
import-dirs:          /usr/lib/ghc-9.4.8/site-local/wuss-2.0.1.2
library-dirs:         /usr/lib/ghc-9.4.8/site-local/wuss-2.0.1.2
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/wuss-2.0.1.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-wuss
hs-libraries:         HSwuss-2.0.1.2-ExKSQnZ8Vg4EuTi7M7pWOx
depends:
    base-4.17.2.1 bytestring-0.11.5.3
    crypton-connection-0.4.1-7QBcy9v4tGs2C8uZQbXbv9 exceptions-0.10.5
    network-3.1.4.0-KDvUj5yehXe5551PZCouYJ
    websockets-0.12.7.3-83F13GfAYCTKaftYiMXY79

haddock-interfaces:   /usr/share/doc/haskell-wuss/html/wuss.haddock
haddock-html:         /usr/share/doc/haskell-wuss/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
